@@ -73,7 +73,8 @@ from ansiblelint._internal.rules import (
 from ansiblelint.config import options
 from ansiblelint.constants import FileType
 from ansiblelint.errors import MatchError
-from ansiblelint.file_utils import Lintable, get_yaml_files
+from ansiblelint.file_utils import Lintable, discover_lintables
+from ansiblelint.text import removeprefix
 
 # ansible-lint doesn't need/want to know about encrypted secrets, so we pass a
 # string as the password to enable such yaml files to be opened and parsed
@@ -87,6 +88,7 @@ _logger = logging.getLogger(__name__)
 
 
 def parse_yaml_from_file(filepath: str) -> AnsibleBaseYAMLObject:
+    """Extract a decrypted YAML object from file."""
     dl = DataLoader()
     if hasattr(dl, 'set_vault_password'):
         dl.set_vault_password(DEFAULT_VAULT_PASSWORD)
@@ -94,6 +96,7 @@ def parse_yaml_from_file(filepath: str) -> AnsibleBaseYAMLObject:
 
 
 def path_dwim(basedir: str, given: str) -> str:
+    """Convert a given path do-what-I-mean style."""
     dl = DataLoader()
     dl.set_basedir(basedir)
     return str(dl.path_dwim(given))
@@ -102,6 +105,15 @@ def path_dwim(basedir: str, given: str) -> str:
 def ansible_template(
     basedir: str, varname: Any, templatevars: Any, **kwargs: Any
 ) -> Any:
+    """Render a templated string."""
+    # `basedir` is the directory containing the lintable file.
+    # Therefore, for tasks in a role, `basedir` has the form
+    # `roles/some_role/tasks`. On the other hand, the search path
+    # is `roles/some_role/{files,templates}`. As a result, the
+    # `tasks` part in the basedir should be stripped stripped.
+    if os.path.basename(basedir) == 'tasks':
+        basedir = os.path.dirname(basedir)
+
     dl = DataLoader()
     dl.set_basedir(basedir)
     templar = Templar(dl, variables=templatevars)
@@ -167,6 +179,7 @@ BLOCK_NAME_TO_ACTION_TYPE_MAP = {
 
 
 def tokenize(line: str) -> Tuple[str, List[str], Dict[str, str]]:
+    """Parse a string task invocation."""
     tokens = line.lstrip().split(" ")
     if tokens[0] == '-':
         tokens = tokens[1:]
@@ -216,6 +229,7 @@ def _set_collections_basedir(basedir: str) -> None:
 
 
 def find_children(lintable: Lintable) -> List[Lintable]:  # noqa: C901
+    """Traverse children of a single file or folder."""
     if not lintable.path.exists():
         return []
     playbook_dir = str(lintable.path.parent)
@@ -267,6 +281,7 @@ def template(
     fail_on_undefined: bool = False,
     **kwargs: str,
 ) -> Any:
+    """Attempt rendering a value with known vars."""
     try:
         value = ansible_template(
             os.path.abspath(basedir),
@@ -285,6 +300,7 @@ def template(
 def play_children(
     basedir: str, item: Tuple[str, Any], parent_type: FileType, playbook_dir: str
 ) -> List[Lintable]:
+    """Flatten the traversed play tasks."""
     delegate_map: Dict[str, Callable[[str, Any, Any, FileType], List[Lintable]]] = {
         'tasks': _taskshandlers_children,
         'pre_tasks': _taskshandlers_children,
@@ -527,7 +543,7 @@ def _sanitize_task(task: Dict[str, Any]) -> Dict[str, Any]:
 
 
 def normalize_task_v2(task: Dict[str, Any]) -> Dict[str, Any]:
-    """Ensure tasks have an action key and strings are converted to python objects."""
+    """Ensure tasks have a normalized action key and strings are converted to python objects."""
     result = dict()
 
     sanitized_task = _sanitize_task(task)
@@ -556,7 +572,17 @@ def normalize_task_v2(task: Dict[str, Any]) -> Dict[str, Any]:
             continue
         result[k] = v
 
-    result['action'] = dict(__ansible_module__=action)
+    if not isinstance(action, str):
+        raise RuntimeError("Task actions can only be strings, got %s" % action)
+    action_unnormalized = action
+    # convert builtin fqn calls to short forms because most rules know only
+    # about short calls but in the future we may switch the normalization to do
+    # the opposite. Mainly we currently consider normalized the module listing
+    # used by `ansible-doc -t module -l 2>/dev/null`
+    action = removeprefix(action, "ansible.builtin.")
+    result['action'] = dict(
+        __ansible_module__=action, __ansible_module_original__=action_unnormalized
+    )
 
     if '_raw_params' in arguments:
         result['action']['__ansible_arguments__'] = arguments['_raw_params'].split(' ')
@@ -573,6 +599,7 @@ def normalize_task_v2(task: Dict[str, Any]) -> Dict[str, Any]:
 
 
 def normalize_task(task: Dict[str, Any], filename: str) -> Dict[str, Any]:
+    """Unify task-like object structures."""
     ansible_action_type = task.get('__ansible_action_type__', 'task')
     if '__ansible_action_type__' in task:
         del task['__ansible_action_type__']
@@ -583,6 +610,7 @@ def normalize_task(task: Dict[str, Any], filename: str) -> Dict[str, Any]:
 
 
 def task_to_str(task: Dict[str, Any]) -> str:
+    """Make a string identifier for the given task."""
     name = task.get("name")
     if name:
         return str(name)
@@ -596,6 +624,7 @@ def task_to_str(task: Dict[str, Any]) -> str:
             if k
             not in [
                 "__ansible_module__",
+                "__ansible_module_original__",
                 "__ansible_arguments__",
                 "__line__",
                 "__file__",
@@ -610,6 +639,7 @@ def task_to_str(task: Dict[str, Any]) -> str:
 def extract_from_list(
     blocks: AnsibleBaseYAMLObject, candidates: List[str]
 ) -> List[Any]:
+    """Get action tasks from block structures."""
     results = list()
     for block in blocks:
         for candidate in candidates:
@@ -625,6 +655,7 @@ def extract_from_list(
 
 
 def add_action_type(actions: AnsibleBaseYAMLObject, action_type: str) -> List[Any]:
+    """Add action markers to task objects."""
     results = list()
     for action in actions:
         # ignore empty task
@@ -636,6 +667,7 @@ def add_action_type(actions: AnsibleBaseYAMLObject, action_type: str) -> List[An
 
 
 def get_action_tasks(yaml: AnsibleBaseYAMLObject, file: Lintable) -> List[Any]:
+    """Get a flattened list of action tasks from the file."""
     tasks = list()
     if file.kind in ['tasks', 'handlers']:
         tasks = add_action_type(yaml, file.kind)
@@ -664,6 +696,7 @@ def get_action_tasks(yaml: AnsibleBaseYAMLObject, file: Lintable) -> List[Any]:
 def get_normalized_tasks(
     yaml: "AnsibleBaseYAMLObject", file: Lintable
 ) -> List[Dict[str, Any]]:
+    """Extract normalized tasks from a file."""
     tasks = get_action_tasks(yaml, file)
     res = []
     for task in tasks:
@@ -688,10 +721,10 @@ def parse_yaml_linenumbers(lintable: Lintable) -> AnsibleBaseYAMLObject:
     def compose_node(parent: yaml.nodes.Node, index: int) -> yaml.nodes.Node:
         # the line number where the previous token has ended (plus empty lines)
         line = loader.line
-        node = Composer.compose_node(loader, parent, index)  # type: ignore
-        node.__line__ = line + 1
+        node = Composer.compose_node(loader, parent, index)
         if not isinstance(node, yaml.nodes.Node):
             raise RuntimeError("Unexpected yaml data.")
+        setattr(node, '__line__', line + 1)
         return node
 
     def construct_mapping(
@@ -720,6 +753,7 @@ def parse_yaml_linenumbers(lintable: Lintable) -> AnsibleBaseYAMLObject:
 
 
 def get_first_cmd_arg(task: Dict[str, Any]) -> Any:
+    """Extract the first arg from a cmd task."""
     try:
         if 'cmd' in task['action']:
             first_cmd_arg = task['action']['cmd'].split()[0]
@@ -730,6 +764,18 @@ def get_first_cmd_arg(task: Dict[str, Any]) -> Any:
     return first_cmd_arg
 
 
+def get_second_cmd_arg(task: Dict[str, Any]) -> Any:
+    """Extract the second arg from a cmd task."""
+    try:
+        if 'cmd' in task['action']:
+            second_cmd_arg = task['action']['cmd'].split()[1]
+        else:
+            second_cmd_arg = task['action']['__ansible_arguments__'][1]
+    except IndexError:
+        return None
+    return second_cmd_arg
+
+
 def is_playbook(filename: str) -> bool:
     """
     Check if the file is a playbook.
@@ -791,7 +837,7 @@ def get_lintables(
             lintables.append(lintable)
     else:
 
-        for filename in get_yaml_files(options):
+        for filename in discover_lintables(options):
 
             p = Path(filename)
             # skip exclusions
@@ -822,7 +868,7 @@ def _extend_with_roles(lintables: List[Lintable]) -> None:
             role = lintable.path
             while role.parent.name != "roles" and role.name:
                 role = role.parent
-            if role.exists:
+            if role.exists and not role.is_file():
                 lintable = Lintable(role, kind="role")
                 if lintable not in lintables:
                     _logger.debug("Added role: %s", lintable)
