@@ -31,10 +31,10 @@ class TestRule(unittest.TestCase):
         ematcher = EMatcherRule.EMatcherRule()
         lintable = Lintable('examples/playbooks/ematcher-rule.yml', kind="playbook")
         matches = ematcher.matchlines(lintable)
-        self.assertEqual(len(matches), 3)
+        assert len(matches) == 3
 
     def test_rule_postmatching(self) -> None:
         rule = UnsetVariableMatcherRule.UnsetVariableMatcherRule()
         lintable = Lintable('examples/playbooks/bracketsmatchtest.yml', kind="playbook")
         matches = rule.matchlines(lintable)
-        self.assertEqual(len(matches), 2)
+        assert len(matches) == 2
